from fastapi import Request
from fastapi import APIRouter
from fastapi import status
from fastapi.responses import HTMLResponse
from fastapi.templating import Jinja2Templates

router = APIRouter()

templates = Jinja2Templates(directory="./templates")

# Path Operations

## Home
@router.get(
    path="/",
    response_class=HTMLResponse,
    status_code=status.HTTP_200_OK,
    summary="Shows home",
    tags=["Home"]
)
def home(request: Request):
    """
        Home.

        This shows the home.

        Returns a HTMLResponse.

    """
    return templates.TemplateResponse(
        name="home.html",
        context={"request": request}
    )


import uvicorn

from fastapi import FastAPI

from routes.routes import router


app = FastAPI(
    title="dailymotion_api",
    description=(
        "This is an API developed un python, using FastAPI."
        "In wich, you can see 10 different videos about gaming."
    )
)

app.include_router(router, prefix="")

if __name__ == "__main__":
    uvicorn.run(
        "main:app",
        host="0.0.0.0",
        port=8000,
        reload=True
    )